[gnome-continuous-yocto/gnomeostree-3.28-rocko: 2083/8267] oeqa.buildperf: use term commit instead of revision



commit 66540ae5c102449ca7417750ce8cdff38e6c801c
Author: Markus Lehtonen <markus lehtonen linux intel com>
Date:   Tue Aug 23 16:11:21 2016 +0300

    oeqa.buildperf: use term commit instead of revision
    
    This is basically a internal change, at this point. Term 'commit' better
    represents the data we actually have. Term 'revision' is more vague and
    could be understood to point to a tag object, for example.
    
    (From OE-Core rev: f49cf7959b8aaa52b79b22a5884c6aa580a50302)
    
    Signed-off-by: Markus Lehtonen <markus lehtonen linux intel com>
    Signed-off-by: Ross Burton <ross burton intel com>
    Signed-off-by: Richard Purdie <richard purdie linuxfoundation org>

 meta/lib/oeqa/buildperf/base.py |   30 +++++++++++++++---------------
 1 files changed, 15 insertions(+), 15 deletions(-)
---
diff --git a/meta/lib/oeqa/buildperf/base.py b/meta/lib/oeqa/buildperf/base.py
index adc3da3..0e77aae 100644
--- a/meta/lib/oeqa/buildperf/base.py
+++ b/meta/lib/oeqa/buildperf/base.py
@@ -96,30 +96,30 @@ class BuildPerfTestResult(unittest.TextTestResult):
             self.repo = GitRepo('.')
         except GitError:
             self.repo = None
-        self.git_revision, self.git_branch = self.get_git_revision()
+        self.git_commit, self.git_branch = self.get_git_revision()
         self.hostname = socket.gethostname()
         self.start_time = self.elapsed_time = None
         self.successes = []
-        log.info("Using Git branch:revision %s:%s", self.git_branch,
-                 self.git_revision)
+        log.info("Using Git branch:commit %s:%s", self.git_branch,
+                 self.git_commit)
 
     def get_git_revision(self):
-        """Get git branch and revision under testing"""
-        rev = os.getenv('OE_BUILDPERFTEST_GIT_REVISION')
+        """Get git branch and commit under testing"""
+        commit = os.getenv('OE_BUILDPERFTEST_GIT_COMMIT')
         branch = os.getenv('OE_BUILDPERFTEST_GIT_BRANCH')
-        if not self.repo and (not rev or not branch):
+        if not self.repo and (not commit or not branch):
             log.info("The current working directory doesn't seem to be a Git "
-                     "repository clone. You can specify branch and revision "
-                     "used in test results with OE_BUILDPERFTEST_GIT_REVISION "
-                     "and OE_BUILDPERFTEST_GIT_BRANCH environment variables")
+                     "repository clone. You can specify branch and commit "
+                     "displayed in test results with OE_BUILDPERFTEST_GIT_BRANCH "
+                     "and OE_BUILDPERFTEST_GIT_COMMIT environment variables")
         else:
-            if not rev:
-                rev = self.repo.rev_parse('HEAD')
+            if not commit:
+                commit = self.repo.rev_parse('HEAD^0')
             if not branch:
                 branch = self.repo.get_current_branch()
                 if not branch:
                     log.debug('Currently on detached HEAD')
-        return str(rev), str(branch)
+        return str(commit), str(branch)
 
     def addSuccess(self, test):
         """Record results from successful tests"""
@@ -165,9 +165,9 @@ class BuildPerfTestResult(unittest.TextTestResult):
                   'test4': ((7, 1), (10, 2))}
 
         if self.repo:
-            git_tag_rev = self.repo.run_cmd(['describe', self.git_revision])
+            git_tag_rev = self.repo.run_cmd(['describe', self.git_commit])
         else:
-            git_tag_rev = self.git_revision
+            git_tag_rev = self.git_commit
 
         values = ['0'] * 12
         for status, (test, msg) in self.all_results():
@@ -183,7 +183,7 @@ class BuildPerfTestResult(unittest.TextTestResult):
         with open(filename, 'a') as fobj:
             fobj.write('{},{}:{},{},'.format(self.hostname,
                                              self.git_branch,
-                                             self.git_revision,
+                                             self.git_commit,
                                              git_tag_rev))
             fobj.write(','.join(values) + '\n')
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]